@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# Copyright (c) 2016-2024 Sullivan Beck. All rights reserved.
+# Copyright (c) 2016-2025 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -18,8 +18,6 @@ $::tests = "
 
 2code Riel => khr
 
-2code 'Zimbabwe Dollar' => zwl
-
 2name KHR => Riel
 
 code2code BZD alpha num => 084
@@ -52,8 +50,6 @@ code2code BZD alpha num => 084
 
 2name zmw => 'Zambian Kwacha'
 
-2name zwl => 'Zimbabwe Dollar'
-
 all_codes 2 => AED AFN
 
 all_names 2 => 'ADB Unit of Account' Afghani
